function x = iMDCT(X)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Efficient computation of inverse MDCT                %
% Windowing is not included and length(X) must be even %
% Olivier Derrien - LMA/CNRS - 02.2015                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Get MDCT size
N = length(X);
if rem(N,2) ~= 0
    disp('Error: input-signal length must be even')
    return
end

% Force X to be a line vector
if size(X,2) == 1
    X = X';
end

% Discrete time and frequency vectors 
t = [0:2*N-1];
f = [0:N-1];

% MDCT computation using FFT
X = X .* exp(-j*pi*(f+0.5)*(N+1)/2/N);
x = fft(X,2*N);
x = sqrt(2/N)*real(x .* exp(-j*pi*t/2/N));
